package org.diagbot.nlp.rule.pretreat;

import org.diagbot.nlp.participle.ParticipleUtil;
import org.diagbot.nlp.participle.word.Lexeme;
import org.diagbot.nlp.participle.word.LexemePath;
import org.diagbot.nlp.rule.module.PreResult;
import org.diagbot.nlp.util.NegativeEnum;
import org.diagbot.nlp.util.NlpUtil;

import java.util.ArrayList;
import java.util.List;

public class PretreatmentPast extends Pretreatment {
    protected NegativeEnum[] nees_past_desc = new NegativeEnum[]{NegativeEnum.PAST_DESC};
    protected NegativeEnum[] nees_disease = new NegativeEnum[]{NegativeEnum.DISEASE};
    protected NegativeEnum[] nees_operation = new NegativeEnum[]{NegativeEnum.OPERATION};
    protected NegativeEnum[] nees_allergy = new NegativeEnum[]{NegativeEnum.ALLERGY};
    protected NegativeEnum[] nees_med = new NegativeEnum[]{NegativeEnum.MEDICINE, NegativeEnum.MEDICINE_NAME, NegativeEnum.MEDICINE_PRD};

    public List<PreResult> analyze(String content) throws java.io.IOException{
        List<PreResult> preResults = new ArrayList<>();
        LexemePath<Lexeme> lexemes = ParticipleUtil.participle(content);
        for (int i = 0; i < lexemes.size(); i++) {
            Lexeme l = lexemes.get(i);
            PreResult result = new PreResult();
            if (NlpUtil.isFeature(l.getProperty(), nees_disease)) {
                result.setUniqueName("诊断--");
                result.setDetailName("诊断--");
                result.setValue(NlpUtil.concept(l, NegativeEnum.DISEASE));
                preResults.add(result);
            } else if (NlpUtil.isFeature(l.getProperty(), nees_past_desc)) {
                result.setUniqueName("既往--");
                result.setDetailName("既往--");
                result.setValue(NlpUtil.concept(l, NegativeEnum.PAST_DESC));
                preResults.add(result);
            } else if (NlpUtil.isFeature(l.getProperty(), nees_operation)) {
                result.setUniqueName("手术--");
                result.setDetailName("手术--");
                result.setValue(NlpUtil.concept(l, NegativeEnum.OPERATION));
                preResults.add(result);
            } else if (NlpUtil.isFeature(l.getProperty(), nees_med)) {
                result.setUniqueName("药品--");
                result.setDetailName("药品--");
                result.setValue(NlpUtil.concept(l, NegativeEnum.MEDICINE));
                preResults.add(result);
            }
            if (l.getText().indexOf("过敏") > -1) {
                int max_find_step = 10;
                int position = i - 1;
                Lexeme leftLexeme;
                while (i - position < max_find_step && position > -1) {
                    leftLexeme = lexemes.get(position);
                    //遇上过敏史信息
                    if (NlpUtil.isFeature(leftLexeme.getProperty(), nees_allergy)) {
                        result.setUniqueName("过敏--");
                        result.setDetailName("过敏--");
                        result.setValue(NlpUtil.concept(leftLexeme, NegativeEnum.ALLERGY) + "过敏");
                        preResults.add(result);
                    }
                    position--;
                }
            }
        }
        return preResults;
    }

    public PreResult createPreResult(LexemePath<Lexeme> lexemes, Lexeme lexeme, int index) {
        return null;
    }

    public String findBodyValue(LexemePath<Lexeme> lexemes, Lexeme lexeme, int index) {
        return null;
    }
}
